aboutsummaryrefslogtreecommitdiff
path: root/src/ipstr.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/ipstr.c')
-rw-r--r--src/ipstr.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/ipstr.c b/src/ipstr.c
index 2787016..90b4cab 100644
--- a/src/ipstr.c
+++ b/src/ipstr.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -19,10 +19,10 @@
#endif
#include <string.h>
#include <ctype.h>
-#include "grecs.h"
+#include "argot.h"
int
-grecs_str_is_ipv4(const char *addr)
+argot_str_is_ipv4(const char *addr)
{
int dot_count = 0;
int digit_count = 0;
@@ -42,7 +42,7 @@ grecs_str_is_ipv4(const char *addr)
}
int
-grecs_str_is_ipv6(const char *addr)
+argot_str_is_ipv6(const char *addr)
{
int col_count = 0; /* Number of colons */
int dcol = 0; /* Did we encounter a double-colon? */
@@ -68,7 +68,7 @@ grecs_str_is_ipv6(const char *addr)
}
int
-grecs_str_is_num(const char *s)
+argot_str_is_num(const char *s)
{
for (; *s; ++s)
if (!isdigit(*s))
@@ -77,12 +77,12 @@ grecs_str_is_num(const char *s)
}
int
-grecs_str_is_ipaddr(const char *addr)
+argot_str_is_ipaddr(const char *addr)
{
if (strchr (addr, '.'))
- return grecs_str_is_ipv4(addr);
+ return argot_str_is_ipv4(addr);
else if (strchr (addr, ':'))
- return grecs_str_is_ipv6(addr);
+ return argot_str_is_ipv6(addr);
return 0;
}
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.